betty.ancestry.presence_role.presence_roles module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.ancestry.presence_role.presence_roles module

Provide presence role implementations.

final class betty.ancestry.presence_role.presence_roles.Attendee

  Bases: `ShorthandPluginBase`, `PresenceRole`

  Someone attended the event (further details unknown).

final class betty.ancestry.presence_role.presence_roles.Beneficiary

  Bases: `ShorthandPluginBase`, `PresenceRole`

  Someone was a benificiary in the event, such as a `betty.ancestry.event_type.event_types.Will`.

final class betty.ancestry.presence_role.presence_roles.Celebrant

  Bases: `ShorthandPluginBase`, `PresenceRole`

  Someone was the celebrant at the event.

  This includes but is not limited to:

  - civil servant

  - religious leader

  - civilian

final class betty.ancestry.presence_role.presence_roles.Informant

  Bases: `ShorthandPluginBase`, `PresenceRole`

  Someone was the informant of an event, e.g. they reported it with a record-keeping institution.

final class betty.ancestry.presence_role.presence_roles.Organizer

  Bases: `ShorthandPluginBase`, `PresenceRole`

  Someone organized the event.

final class betty.ancestry.presence_role.presence_roles.Speaker

  Bases: `ShorthandPluginBase`, `PresenceRole`

  Someone performed public speaking at the event.

final class betty.ancestry.presence_role.presence_roles.Subject

  Bases: `ShorthandPluginBase`, `PresenceRole`

  Someone was the subject of the event.

  The meaning of this role depends on the event type. For example, for `betty.ancestry.event_type.event_types.Marriage`, the subjects are the people who got married. For `betty.ancestry.event_type.event_types.Death` it is the person who died.

final class betty.ancestry.presence_role.presence_roles.Unknown

  Bases: `ShorthandPluginBase`, `PresenceRole`

  Someone’s role in an event is unknown.

final class betty.ancestry.presence_role.presence_roles.Witness

  Bases: `ShorthandPluginBase`, `PresenceRole`

  Someone witnessed the event.